==> mssdk-0.0.5.tar.gz: mssdk-0.0.5/mssdk/obor/cons.py <==
# -*- coding:utf-8 -*-
# /usr/bin/env python
"""
Author: Albert King
date: 2019/9/30 13:58
contact: jindaxiang@163.com
desc: 一带一路配置文件
"""

countries_dict = {
    'obor_report_all': [
        '中国',
        '蒙古国',
        '韩国',
        '新西兰',
        '东帝汶',
        '新加坡',
        '马来西亚',
        '泰国',
        '印度尼西亚',
        '菲律宾',
        '文莱',
        '柬埔寨',
        '缅甸',
        '老挝',
        '越南',
        '哈萨克斯坦',
        '乌兹别克斯坦',
        '土库曼斯坦',
        '塔吉克斯坦',
        '吉尔吉斯斯坦',
        '格鲁吉亚',
        '阿塞拜疆',
        '亚美尼亚',
        '伊朗',
        '伊拉克',
        '土耳其',
        '叙利亚',
        '约旦',
        '黎巴嫩',
        '以色列',
        '巴勒斯坦',
        '沙特阿拉伯',
        '也门',
        '阿曼',
        '阿联酋',
        '卡塔尔',
        '科威特',
        '巴林',
        '印度',
        '巴基斯坦',
        '孟加拉',
        '阿富汗',
        '斯里兰卡',
        '马尔代夫',
        '尼泊尔',
        '不丹',
        '俄罗斯',
        '乌克兰',
        '白俄罗斯',
        '摩尔多瓦',
        '波兰',
        '立陶宛',
        '爱沙尼亚',
        '拉脱维亚',
        '捷克',
        '斯洛伐克',
        '匈牙利',
        '斯洛文尼亚',
        '克罗地亚',
        '波黑',
        '黑山',
        '塞尔维亚',
        '阿尔巴尼亚',
        '罗马尼亚',
        '保加利亚',
        '马其顿',
        '南非',
        '摩洛哥',
        '埃塞俄比亚',
        '马达加斯加',
        '巴拿马',
        '埃及'],

    'obor_report_plates_countries': {
        '亚洲大洋洲地区': [
            '中国',
            '蒙古国',
            '韩国',
            '新西兰',
            '东帝汶',
            '新加坡',
            '马来西亚',
            '泰国',
            '印度尼西亚',
            '菲律宾',
            '文莱',
            '柬埔寨',
            '缅甸',
            '老挝',
            '越南'],
        '中亚地区': [
            '哈萨克斯坦',
            '乌兹别克斯坦',
            '土库曼斯坦',
            '塔吉克斯坦',
            '吉尔吉斯斯坦'],
        '西亚地区': [
            '格鲁吉亚',
            '阿塞拜疆',
            '亚美尼亚',
            '伊朗',
            '伊拉克',
            '土耳其',
            '叙利亚',
            '约旦',
            '黎巴嫩',
            '以色列',
            '巴勒斯坦',
            '沙特阿拉伯',
            '也门',
            '阿曼',
            '阿联酋',
            '卡塔尔',
            '科威特',
            '巴林'],
        '南亚地区': [
            '印度',
            '巴基斯坦',
            '孟加拉',
            '阿富汗',
            '斯里兰卡',
            '马尔代夫',
            '尼泊尔',
            '不丹'],
        '东欧地区': [
            '俄罗斯',
            '乌克兰',
            '白俄罗斯',
            '摩尔多瓦',
            '波兰',
            '立陶宛',
            '爱沙尼亚',
            '拉脱维亚',
            '捷克',
            '斯洛伐克',
            '匈牙利',
            '斯洛文尼亚',
            '克罗地亚',
            '波黑',
            '黑山',
            '塞尔维亚',
            '阿尔巴尼亚',
            '罗马尼亚',
            '保加利亚',
            '马其顿'],
        '非洲及拉美地区': [
            '南非',
            '摩洛哥',
            '埃塞俄比亚',
            '马达加斯加',
            '巴拿马',
            '埃及']},
    'invest_countries_index_list': [
        '中国',
        '丹麦',
        '乌克兰',
        '乌干达',
        '以色列',
        '伊拉克',
        '俄罗斯',
        '保加利亚',
        '克罗地亚',
        '冰岛',
        '加拿大',
        '匈牙利',
        '南非',
        '博茨瓦纳',
        '卡塔尔',
        '卢旺达',
        '卢森堡',
        '印度',
        '印度尼西亚',
        '厄瓜多尔',
        '台湾',
        '哈萨克斯坦',
        '哥伦比亚',
        '哥斯达黎加',
        '土耳其',
        '坦桑尼亚',
        '埃及',
        '塞尔维亚',
        '塞浦路斯',
        '墨西哥',
        '奥地利',
        '委内瑞拉',
        '孟加拉国',
        '尼日利亚',
        '巴勒斯坦领土',
        '巴基斯坦',
        '巴林',
        '巴西',
        '希腊',
        '德国',
        '意大利',
        '拉脱维亚',
        '挪威',
        '捷克',
        '摩洛哥',
        '斯洛伐克',
        '斯洛文尼亚',
        '斯里兰卡',
        '新加坡',
        '新西兰',
        '日本',
        '智利',
        '比利时',
        '毛里求斯',
        '沙特阿拉伯',
        '法国',
        '波兰',
        '波黑',
        '泰国',
        '津巴布韦',
        '澳大利亚',
        '爱尔兰',
        '爱沙尼亚',
        '牙买加',
        '瑞典',
        '瑞士',
        '科威特',
        '科特迪亚',
        '秘鲁',
        '突尼斯',
        '立陶宛',
        '约旦',
        '纳米比亚',
        '罗马尼亚',
        '美国',
        '肯尼亚',
        '芬兰',
        '英国',
        '荷兰',
        '菲律宾',
        '葡萄牙',
        '蒙古',
        '西班牙',
        '赞比亚',
        '越南',
        '阿拉伯联合酋长国',
        '阿曼',
        '阿根廷',
        '韩国',
        '香港',
        '马尔他',
        '马拉维',
        '马来西亚',
        '黎巴嫩',
        '黑山'
    ],
    'report_map_invest': {
        "中国": "中国",
        "蒙古国": "蒙古",
        "韩国": "韩国",
        "新西兰": "新西兰",
        "东帝汶": "",
        "新加坡": "新加坡",
        "马来西亚": "马来西亚",
        "泰国": "泰国",
        "印度尼西亚": "印度尼西亚",
        "菲律宾": "菲律宾",
        "文莱": "",
        "柬埔寨": "",
        "缅甸": "",
        "老挝": "",
        "越南": "越南",
        "哈萨克斯坦": "哈萨克斯坦",
        "乌兹别克斯坦": "",
        "土库曼斯坦": "",
        "塔吉克斯坦": "",
        "吉尔吉斯斯坦": "",
        "格鲁吉亚": "",
        "阿塞拜疆": "",
        "亚美尼亚": "",
        "伊朗": "",
        "伊拉克": "伊拉克",
        "土耳其": "土耳其",
        "叙利亚": "",
        "约旦": "约旦",
        "黎巴嫩": "黎巴嫩",
        "以色列": "以色列",
        "巴勒斯坦": "巴勒斯坦领土",
        "沙特阿拉伯": "沙特阿拉伯",
        "也门": "",
        "阿曼": "阿曼",
        "阿联酋": "阿拉伯联合酋长国",
        "卡塔尔": "卡塔尔",
        "科威特": "科威特",
        "巴林": "巴林",
        "印度": "印度",
        "巴基斯坦": "巴基斯坦",
        "孟加拉": "孟加拉国",
        "阿富汗": "",
        "斯里兰卡": "斯里兰卡",
        "马尔代夫": "",
        "尼泊尔": "",
        "不丹": "",
        "俄罗斯": "俄罗斯",
        "乌克兰": "乌克兰",
        "白俄罗斯": "",
        "摩尔多瓦": "",
        "波兰": "波兰",
        "立陶宛": "立陶宛",
        "爱沙尼亚": "爱沙尼亚",
        "拉脱维亚": "拉脱维亚",
        "捷克": "捷克",
        "斯洛伐克": "斯洛伐克",
        "匈牙利": "匈牙利",
        "斯洛文尼亚": "斯洛文尼亚",
        "克罗地亚": "克罗地亚",
        "波黑": "波黑",
        "黑山": "黑山",
        "塞尔维亚": "塞尔维亚",
        "阿尔巴尼亚": "",
        "罗马尼亚": "罗马尼亚",
        "保加利亚": "保加利亚",
        "马其顿": "",
        "南非": "南非",
        "摩洛哥": "摩洛哥",
        "埃塞俄比亚": "",
        "马达加斯加": "",
        "巴拿马": "",
        "埃及": "埃及"
    }

}

==> mssdk-0.0.9.tar.gz: mssdk-0.0.9/mssdk/obor/cons.py <==
# -*- coding:utf-8 -*-
# /usr/bin/env python
"""
Date: 2019/9/30 13:58
Desc: 一带一路配置文件
"""

countries_dict = {
    'obor_report_all': [
        '中国',
        '蒙古国',
        '韩国',
        '新西兰',
        '东帝汶',
        '新加坡',
        '马来西亚',
        '泰国',
        '印度尼西亚',
        '菲律宾',
        '文莱',
        '柬埔寨',
        '缅甸',
        '老挝',
        '越南',
        '哈萨克斯坦',
        '乌兹别克斯坦',
        '土库曼斯坦',
        '塔吉克斯坦',
        '吉尔吉斯斯坦',
        '格鲁吉亚',
        '阿塞拜疆',
        '亚美尼亚',
        '伊朗',
        '伊拉克',
        '土耳其',
        '叙利亚',
        '约旦',
        '黎巴嫩',
        '以色列',
        '巴勒斯坦',
        '沙特阿拉伯',
        '也门',
        '阿曼',
        '阿联酋',
        '卡塔尔',
        '科威特',
        '巴林',
        '印度',
        '巴基斯坦',
        '孟加拉',
        '阿富汗',
        '斯里兰卡',
        '马尔代夫',
        '尼泊尔',
        '不丹',
        '俄罗斯',
        '乌克兰',
        '白俄罗斯',
        '摩尔多瓦',
        '波兰',
        '立陶宛',
        '爱沙尼亚',
        '拉脱维亚',
        '捷克',
        '斯洛伐克',
        '匈牙利',
        '斯洛文尼亚',
        '克罗地亚',
        '波黑',
        '黑山',
        '塞尔维亚',
        '阿尔巴尼亚',
        '罗马尼亚',
        '保加利亚',
        '马其顿',
        '南非',
        '摩洛哥',
        '埃塞俄比亚',
        '马达加斯加',
        '巴拿马',
        '埃及'],

    'obor_report_plates_countries': {
        '亚洲大洋洲地区': [
            '中国',
            '蒙古国',
            '韩国',
            '新西兰',
            '东帝汶',
            '新加坡',
            '马来西亚',
            '泰国',
            '印度尼西亚',
            '菲律宾',
            '文莱',
            '柬埔寨',
            '缅甸',
            '老挝',
            '越南'],
        '中亚地区': [
            '哈萨克斯坦',
            '乌兹别克斯坦',
            '土库曼斯坦',
            '塔吉克斯坦',
            '吉尔吉斯斯坦'],
        '西亚地区': [
            '格鲁吉亚',
            '阿塞拜疆',
            '亚美尼亚',
            '伊朗',
            '伊拉克',
            '土耳其',
            '叙利亚',
            '约旦',
            '黎巴嫩',
            '以色列',
            '巴勒斯坦',
            '沙特阿拉伯',
            '也门',
            '阿曼',
            '阿联酋',
            '卡塔尔',
            '科威特',
            '巴林'],
        '南亚地区': [
            '印度',
            '巴基斯坦',
            '孟加拉',
            '阿富汗',
            '斯里兰卡',
            '马尔代夫',
            '尼泊尔',
            '不丹'],
        '东欧地区': [
            '俄罗斯',
            '乌克兰',
            '白俄罗斯',
            '摩尔多瓦',
            '波兰',
            '立陶宛',
            '爱沙尼亚',
            '拉脱维亚',
            '捷克',
            '斯洛伐克',
            '匈牙利',
            '斯洛文尼亚',
            '克罗地亚',
            '波黑',
            '黑山',
            '塞尔维亚',
            '阿尔巴尼亚',
            '罗马尼亚',
            '保加利亚',
            '马其顿'],
        '非洲及拉美地区': [
            '南非',
            '摩洛哥',
            '埃塞俄比亚',
            '马达加斯加',
            '巴拿马',
            '埃及']},
    'invest_countries_index_list': [
        '中国',
        '丹麦',
        '乌克兰',
        '乌干达',
        '以色列',
        '伊拉克',
        '俄罗斯',
        '保加利亚',
        '克罗地亚',
        '冰岛',
        '加拿大',
        '匈牙利',
        '南非',
        '博茨瓦纳',
        '卡塔尔',
        '卢旺达',
        '卢森堡',
        '印度',
        '印度尼西亚',
        '厄瓜多尔',
        '台湾',
        '哈萨克斯坦',
        '哥伦比亚',
        '哥斯达黎加',
        '土耳其',
        '坦桑尼亚',
        '埃及',
        '塞尔维亚',
        '塞浦路斯',
        '墨西哥',
        '奥地利',
        '委内瑞拉',
        '孟加拉国',
        '尼日利亚',
        '巴勒斯坦领土',
        '巴基斯坦',
        '巴林',
        '巴西',
        '希腊',
        '德国',
        '意大利',
        '拉脱维亚',
        '挪威',
        '捷克',
        '摩洛哥',
        '斯洛伐克',
        '斯洛文尼亚',
        '斯里兰卡',
        '新加坡',
        '新西兰',
        '日本',
        '智利',
        '比利时',
        '毛里求斯',
        '沙特阿拉伯',
        '法国',
        '波兰',
        '波黑',
        '泰国',
        '津巴布韦',
        '澳大利亚',
        '爱尔兰',
        '爱沙尼亚',
        '牙买加',
        '瑞典',
        '瑞士',
        '科威特',
        '科特迪亚',
        '秘鲁',
        '突尼斯',
        '立陶宛',
        '约旦',
        '纳米比亚',
        '罗马尼亚',
        '美国',
        '肯尼亚',
        '芬兰',
        '英国',
        '荷兰',
        '菲律宾',
        '葡萄牙',
        '蒙古',
        '西班牙',
        '赞比亚',
        '越南',
        '阿拉伯联合酋长国',
        '阿曼',
        '阿根廷',
        '韩国',
        '香港',
        '马尔他',
        '马拉维',
        '马来西亚',
        '黎巴嫩',
        '黑山'
    ],
    'report_map_invest': {
        "中国": "中国",
        "蒙古国": "蒙古",
        "韩国": "韩国",
        "新西兰": "新西兰",
        "东帝汶": "",
        "新加坡": "新加坡",
        "马来西亚": "马来西亚",
        "泰国": "泰国",
        "印度尼西亚": "印度尼西亚",
        "菲律宾": "菲律宾",
        "文莱": "",
        "柬埔寨": "",
        "缅甸": "",
        "老挝": "",
        "越南": "越南",
        "哈萨克斯坦": "哈萨克斯坦",
        "乌兹别克斯坦": "",
        "土库曼斯坦": "",
        "塔吉克斯坦": "",
        "吉尔吉斯斯坦": "",
        "格鲁吉亚": "",
        "阿塞拜疆": "",
        "亚美尼亚": "",
        "伊朗": "",
        "伊拉克": "伊拉克",
        "土耳其": "土耳其",
        "叙利亚": "",
        "约旦": "约旦",
        "黎巴嫩": "黎巴嫩",
        "以色列": "以色列",
        "巴勒斯坦": "巴勒斯坦领土",
        "沙特阿拉伯": "沙特阿拉伯",
        "也门": "",
        "阿曼": "阿曼",
        "阿联酋": "阿拉伯联合酋长国",
        "卡塔尔": "卡塔尔",
        "科威特": "科威特",
        "巴林": "巴林",
        "印度": "印度",
        "巴基斯坦": "巴基斯坦",
        "孟加拉": "孟加拉国",
        "阿富汗": "",
        "斯里兰卡": "斯里兰卡",
        "马尔代夫": "",
        "尼泊尔": "",
        "不丹": "",
        "俄罗斯": "俄罗斯",
        "乌克兰": "乌克兰",
        "白俄罗斯": "",
        "摩尔多瓦": "",
        "波兰": "波兰",
        "立陶宛": "立陶宛",
        "爱沙尼亚": "爱沙尼亚",
        "拉脱维亚": "拉脱维亚",
        "捷克": "捷克",
        "斯洛伐克": "斯洛伐克",
        "匈牙利": "匈牙利",
        "斯洛文尼亚": "斯洛文尼亚",
        "克罗地亚": "克罗地亚",
        "波黑": "波黑",
        "黑山": "黑山",
        "塞尔维亚": "塞尔维亚",
        "阿尔巴尼亚": "",
        "罗马尼亚": "罗马尼亚",
        "保加利亚": "保加利亚",
        "马其顿": "",
        "南非": "南非",
        "摩洛哥": "摩洛哥",
        "埃塞俄比亚": "",
        "马达加斯加": "",
        "巴拿马": "",
        "埃及": "埃及"
    }

}
